import { join } from "path";
import { existsSync } from "fs";
import pathToPosix from "./pathToPosix.js";
const IMMUTABLE_CACHE_CONTROL_HEADER = "public, max-age=31536000, immutable";
const SERVER_CACHE_CONTROL_HEADER = "public, max-age=0, s-maxage=2678400, must-revalidate";
const DEFAULT_PUBLIC_DIR_CACHE_CONTROL = "public, max-age=31536000, must-revalidate";
const filterNonExistentPathKeys = (config) => {
    return Object.keys(config).reduce((newConfig, nextConfigKey) => ({
        ...newConfig,
        ...(existsSync(config[nextConfigKey].path)
            ? { [nextConfigKey]: config[nextConfigKey] }
            : {})
    }), {});
};
const readAssetsDirectory = (options) => {
    const { assetsDirectory } = options;
    // Ensure these are posix paths so they are compatible with AWS S3
    const publicFiles = pathToPosix(join(assetsDirectory, "public"));
    const staticFiles = pathToPosix(join(assetsDirectory, "static"));
    const staticPages = pathToPosix(join(assetsDirectory, "static-pages"));
    const nextData = pathToPosix(join(assetsDirectory, "_next", "data"));
    const nextStatic = pathToPosix(join(assetsDirectory, "_next", "static"));
    return filterNonExistentPathKeys({
        publicFiles: {
            path: publicFiles,
            cacheControl: DEFAULT_PUBLIC_DIR_CACHE_CONTROL
        },
        staticFiles: {
            path: staticFiles,
            cacheControl: DEFAULT_PUBLIC_DIR_CACHE_CONTROL
        },
        staticPages: {
            path: staticPages,
            cacheControl: SERVER_CACHE_CONTROL_HEADER
        },
        nextData: { path: nextData, cacheControl: SERVER_CACHE_CONTROL_HEADER },
        nextStatic: {
            path: nextStatic,
            cacheControl: IMMUTABLE_CACHE_CONTROL_HEADER
        }
    });
};
export { readAssetsDirectory };
//# sourceMappingURL=readAssetsDirectory.js.map